==> eam-wshub-proxyclient-11.4-8-sources.jar: net/datastream/schemas/mp_entities/equipmentgeneration_001/CopyData.java <==

package net.datastream.schemas.mp_entities.equipmentgeneration_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COPYCOMMENTS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COPYDOCUMENTS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COPYCUSTOMFIELDS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COPYDEPRECIATION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COPYMETERS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COPYPARTSASSOCIATED" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COPYWARRANTIES" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COPYPMSCHEDULES" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COPYMAINTENANCEPATTERNS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COPYSAFETY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COPYPERMITS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COPYCALIBRATION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COPYTESTPOINTS" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "copycomments",
    "copydocuments",
    "copycustomfields",
    "copydepreciation",
    "copymeters",
    "copypartsassociated",
    "copywarranties",
    "copypmschedules",
    "copymaintenancepatterns",
    "copysafety",
    "copypermits",
    "copycalibration",
    "copytestpoints"
})
@XmlRootElement(name = "CopyData")
public class CopyData {

    @XmlElement(name = "COPYCOMMENTS", namespace = "http://schemas.datastream.net/MP_fields")
    protected String copycomments;
    @XmlElement(name = "COPYDOCUMENTS", namespace = "http://schemas.datastream.net/MP_fields")
    protected String copydocuments;
    @XmlElement(name = "COPYCUSTOMFIELDS", namespace = "http://schemas.datastream.net/MP_fields")
    protected String copycustomfields;
    @XmlElement(name = "COPYDEPRECIATION", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "true")
    protected String copydepreciation;
    @XmlElement(name = "COPYMETERS", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "true")
    protected String copymeters;
    @XmlElement(name = "COPYPARTSASSOCIATED", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "true")
    protected String copypartsassociated;
    @XmlElement(name = "COPYWARRANTIES", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "true")
    protected String copywarranties;
    @XmlElement(name = "COPYPMSCHEDULES", namespace = "http://schemas.datastream.net/MP_fields")
    protected String copypmschedules;
    @XmlElement(name = "COPYMAINTENANCEPATTERNS", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "true")
    protected String copymaintenancepatterns;
    @XmlElement(name = "COPYSAFETY", namespace = "http://schemas.datastream.net/MP_fields")
    protected String copysafety;
    @XmlElement(name = "COPYPERMITS", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "true")
    protected String copypermits;
    @XmlElement(name = "COPYCALIBRATION", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "true")
    protected String copycalibration;
    @XmlElement(name = "COPYTESTPOINTS", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "true")
    protected String copytestpoints;

    /**
     * Obtient la valeur de la propriété copycomments.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOPYCOMMENTS() {
        return copycomments;
    }

    /**
     * Définit la valeur de la propriété copycomments.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOPYCOMMENTS(String value) {
        this.copycomments = value;
    }

    /**
     * Obtient la valeur de la propriété copydocuments.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOPYDOCUMENTS() {
        return copydocuments;
    }

    /**
     * Définit la valeur de la propriété copydocuments.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOPYDOCUMENTS(String value) {
        this.copydocuments = value;
    }

    /**
     * Obtient la valeur de la propriété copycustomfields.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOPYCUSTOMFIELDS() {
        return copycustomfields;
    }

    /**
     * Définit la valeur de la propriété copycustomfields.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOPYCUSTOMFIELDS(String value) {
        this.copycustomfields = value;
    }

    /**
     * Obtient la valeur de la propriété copydepreciation.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOPYDEPRECIATION() {
        return copydepreciation;
    }

    /**
     * Définit la valeur de la propriété copydepreciation.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOPYDEPRECIATION(String value) {
        this.copydepreciation = value;
    }

    /**
     * Obtient la valeur de la propriété copymeters.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOPYMETERS() {
        return copymeters;
    }

    /**
     * Définit la valeur de la propriété copymeters.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOPYMETERS(String value) {
        this.copymeters = value;
    }

    /**
     * Obtient la valeur de la propriété copypartsassociated.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOPYPARTSASSOCIATED() {
        return copypartsassociated;
    }

    /**
     * Définit la valeur de la propriété copypartsassociated.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOPYPARTSASSOCIATED(String value) {
        this.copypartsassociated = value;
    }

    /**
     * Obtient la valeur de la propriété copywarranties.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOPYWARRANTIES() {
        return copywarranties;
    }

    /**
     * Définit la valeur de la propriété copywarranties.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOPYWARRANTIES(String value) {
        this.copywarranties = value;
    }

    /**
     * Obtient la valeur de la propriété copypmschedules.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOPYPMSCHEDULES() {
        return copypmschedules;
    }

    /**
     * Définit la valeur de la propriété copypmschedules.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOPYPMSCHEDULES(String value) {
        this.copypmschedules = value;
    }

    /**
     * Obtient la valeur de la propriété copymaintenancepatterns.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOPYMAINTENANCEPATTERNS() {
        return copymaintenancepatterns;
    }

    /**
     * Définit la valeur de la propriété copymaintenancepatterns.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOPYMAINTENANCEPATTERNS(String value) {
        this.copymaintenancepatterns = value;
    }

    /**
     * Obtient la valeur de la propriété copysafety.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOPYSAFETY() {
        return copysafety;
    }

    /**
     * Définit la valeur de la propriété copysafety.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOPYSAFETY(String value) {
        this.copysafety = value;
    }

    /**
     * Obtient la valeur de la propriété copypermits.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOPYPERMITS() {
        return copypermits;
    }

    /**
     * Définit la valeur de la propriété copypermits.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOPYPERMITS(String value) {
        this.copypermits = value;
    }

    /**
     * Obtient la valeur de la propriété copycalibration.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOPYCALIBRATION() {
        return copycalibration;
    }

    /**
     * Définit la valeur de la propriété copycalibration.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOPYCALIBRATION(String value) {
        this.copycalibration = value;
    }

    /**
     * Obtient la valeur de la propriété copytestpoints.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOPYTESTPOINTS() {
        return copytestpoints;
    }

    /**
     * Définit la valeur de la propriété copytestpoints.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOPYTESTPOINTS(String value) {
        this.copytestpoints = value;
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_entities/equipmentgeneration_001/CopyData.java <==

package net.datastream.schemas.mp_entities.equipmentgeneration_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COPYCOMMENTS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COPYDOCUMENTS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COPYCUSTOMFIELDS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COPYDEPRECIATION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COPYMETERS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COPYPARTSASSOCIATED" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COPYWARRANTIES" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COPYPMSCHEDULES" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COPYMAINTENANCEPATTERNS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COPYSAFETY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COPYPERMITS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COPYCALIBRATION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COPYTESTPOINTS" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "copycomments",
    "copydocuments",
    "copycustomfields",
    "copydepreciation",
    "copymeters",
    "copypartsassociated",
    "copywarranties",
    "copypmschedules",
    "copymaintenancepatterns",
    "copysafety",
    "copypermits",
    "copycalibration",
    "copytestpoints"
})
@XmlRootElement(name = "CopyData")
public class CopyData {

    @XmlElement(name = "COPYCOMMENTS", namespace = "http://schemas.datastream.net/MP_fields")
    protected String copycomments;
    @XmlElement(name = "COPYDOCUMENTS", namespace = "http://schemas.datastream.net/MP_fields")
    protected String copydocuments;
    @XmlElement(name = "COPYCUSTOMFIELDS", namespace = "http://schemas.datastream.net/MP_fields")
    protected String copycustomfields;
    @XmlElement(name = "COPYDEPRECIATION", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "true")
    protected String copydepreciation;
    @XmlElement(name = "COPYMETERS", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "true")
    protected String copymeters;
    @XmlElement(name = "COPYPARTSASSOCIATED", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "true")
    protected String copypartsassociated;
    @XmlElement(name = "COPYWARRANTIES", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "true")
    protected String copywarranties;
    @XmlElement(name = "COPYPMSCHEDULES", namespace = "http://schemas.datastream.net/MP_fields")
    protected String copypmschedules;
    @XmlElement(name = "COPYMAINTENANCEPATTERNS", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "true")
    protected String copymaintenancepatterns;
    @XmlElement(name = "COPYSAFETY", namespace = "http://schemas.datastream.net/MP_fields")
    protected String copysafety;
    @XmlElement(name = "COPYPERMITS", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "true")
    protected String copypermits;
    @XmlElement(name = "COPYCALIBRATION", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "true")
    protected String copycalibration;
    @XmlElement(name = "COPYTESTPOINTS", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "true")
    protected String copytestpoints;

    /**
     * Gets the value of the copycomments property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOPYCOMMENTS() {
        return copycomments;
    }

    /**
     * Sets the value of the copycomments property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOPYCOMMENTS(String value) {
        this.copycomments = value;
    }

    /**
     * Gets the value of the copydocuments property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOPYDOCUMENTS() {
        return copydocuments;
    }

    /**
     * Sets the value of the copydocuments property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOPYDOCUMENTS(String value) {
        this.copydocuments = value;
    }

    /**
     * Gets the value of the copycustomfields property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOPYCUSTOMFIELDS() {
        return copycustomfields;
    }

    /**
     * Sets the value of the copycustomfields property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOPYCUSTOMFIELDS(String value) {
        this.copycustomfields = value;
    }

    /**
     * Gets the value of the copydepreciation property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOPYDEPRECIATION() {
        return copydepreciation;
    }

    /**
     * Sets the value of the copydepreciation property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOPYDEPRECIATION(String value) {
        this.copydepreciation = value;
    }

    /**
     * Gets the value of the copymeters property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOPYMETERS() {
        return copymeters;
    }

    /**
     * Sets the value of the copymeters property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOPYMETERS(String value) {
        this.copymeters = value;
    }

    /**
     * Gets the value of the copypartsassociated property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOPYPARTSASSOCIATED() {
        return copypartsassociated;
    }

    /**
     * Sets the value of the copypartsassociated property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOPYPARTSASSOCIATED(String value) {
        this.copypartsassociated = value;
    }

    /**
     * Gets the value of the copywarranties property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOPYWARRANTIES() {
        return copywarranties;
    }

    /**
     * Sets the value of the copywarranties property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOPYWARRANTIES(String value) {
        this.copywarranties = value;
    }

    /**
     * Gets the value of the copypmschedules property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOPYPMSCHEDULES() {
        return copypmschedules;
    }

    /**
     * Sets the value of the copypmschedules property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOPYPMSCHEDULES(String value) {
        this.copypmschedules = value;
    }

    /**
     * Gets the value of the copymaintenancepatterns property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOPYMAINTENANCEPATTERNS() {
        return copymaintenancepatterns;
    }

    /**
     * Sets the value of the copymaintenancepatterns property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOPYMAINTENANCEPATTERNS(String value) {
        this.copymaintenancepatterns = value;
    }

    /**
     * Gets the value of the copysafety property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOPYSAFETY() {
        return copysafety;
    }

    /**
     * Sets the value of the copysafety property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOPYSAFETY(String value) {
        this.copysafety = value;
    }

    /**
     * Gets the value of the copypermits property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOPYPERMITS() {
        return copypermits;
    }

    /**
     * Sets the value of the copypermits property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOPYPERMITS(String value) {
        this.copypermits = value;
    }

    /**
     * Gets the value of the copycalibration property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOPYCALIBRATION() {
        return copycalibration;
    }

    /**
     * Sets the value of the copycalibration property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOPYCALIBRATION(String value) {
        this.copycalibration = value;
    }

    /**
     * Gets the value of the copytestpoints property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOPYTESTPOINTS() {
        return copytestpoints;
    }

    /**
     * Sets the value of the copytestpoints property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOPYTESTPOINTS(String value) {
        this.copytestpoints = value;
    }

}
